@@ -36,10 +36,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "11.0.14.1";
+        "11.0.15";
 
     private static final String java_version_date =
-        "2022-02-08";
+        "2022-04-19";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +47,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.14.1+1";
+        "11.0.15+3";
 
     private static final String VERSION_NUMBER =
-        "11.0.14.1";
+        "11.0.15";
 
     private static final String VERSION_BUILD =
-        "1";
+        "3";
 
     private static final String VERSION_PRE =
         "";
