@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -902,6 +902,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Ira\u0144ski cas",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Easter = new String[] {
                "standardny cas Jat\u0161owneje kupy",
                "",
@@ -1225,16 +1233,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", EMPTY_ZONE },
             { "Asia/Aden", Arabian },
             { "America/Cuiaba", Amazon },
             { "Africa/Nairobi", Africa_Eastern },
@@ -1268,6 +1267,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Yerevan", Armenia },
             { "Europe/Brussels", Europe_Central },
             { "timezone.excity.Atlantic/Reykjavik", "Reykjav\u00edk" },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "Fid\u017ei" },
             { "timezone.excity.Asia/Kamchatka", "Kam\u010datka" },
             { "Europe/Warsaw", Europe_Central },
@@ -1293,8 +1293,10 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.America/El_Salvador", "El Salvador" },
             { "Asia/Dubai", Gulf },
             { "Europe/Isle_of_Man", GMT },
+            { "BET", Brasilia },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Jat\u0161owne kupy" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "America/Argentina/Salta", Argentina },
             { "Africa/Tunis", Europe_Central },
@@ -1328,6 +1330,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
             { "timezone.excity.Africa/Cairo", "Kairo" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "Africa/Malabo", Africa_Western },
             { "timezone.excity.Europe/Warsaw", "War\u0161awa" },
@@ -1349,16 +1352,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Anguilla", Atlantic },
             { "Asia/Dili", East_Timor },
             { "Africa/Bamako", GMT },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Pacific/Wallis", Wallis },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1400,16 +1393,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Antarctica/DumontDUrville", "Dumont D\u2019Urville" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "America/Cayenne", French_Guiana },
@@ -1426,6 +1409,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "Pacific/Enderbury", Phoenix_Islands },
             { "America/Juneau", Alaska },
+            { "CNT", Newfoundland },
             { "America/Indiana/Vevay", America_Eastern },
             { "timezone.excity.Europe/Volgograd", "Wolgograd" },
             { "timezone.excity.Europe/Rome", "Rom" },
@@ -1458,6 +1442,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
             { "Indian/Christmas", Christmas },
             { "America/Antigua", Atlantic },
+            { "NET", Armenia },
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "America/Inuvik", America_Mountain },
@@ -1510,12 +1495,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Europe/Amsterdam", Europe_Central },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Ho-Chi-Minh-m\u011bsto" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "Africa/Accra", GMT },
             { "America/Maceio", Brasilia },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburg" },
+            { "CST", America_Central },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Europe/Dublin",
                 new String[] {
@@ -1531,6 +1518,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
             { "America/Nassau", America_Eastern },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1539,6 +1527,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Calcutta", "Kalkutta" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Aqtobe", "Aktobe" },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Libreville", Africa_Western },
@@ -1551,12 +1540,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "America/Cayman", America_Eastern },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Baghdad", Arabian },
             { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "America/Tijuana", America_Pacific },
             { "timezone.excity.America/Mexico_City", "Mexiko-m\u011bsto" },
             { "Pacific/Saipan", Chamorro },
@@ -1569,10 +1560,12 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Lisbon", "Lissabon" },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Sapori\u017eja" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -1585,32 +1578,13 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Bangkok", Indochina },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Thunder_Bay", America_Eastern },
             { "timezone.excity.America/Port_of_Spain", "Port-of-Spain" },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Mexico_City", America_Central },
             { "Antarctica/Vostok", Vostok },
             { "Europe/Andorra", Europe_Central },
@@ -1623,6 +1597,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Europe/Oslo", Europe_Central },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.Africa/Mogadishu", "Mogadi\u0161u" },
@@ -1643,6 +1618,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Lome", "Lom\u00e9" },
             { "Africa/Kampala", Africa_Eastern },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "America/Edmonton", America_Mountain },
             { "Europe/Podgorica", Europe_Central },
@@ -1719,9 +1695,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Novosibirsk", "Nowosibirsk" },
             { "Africa/Harare", Africa_Central },
             { "America/Nome", Alaska },
+            { "NST", New_Zealand },
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Khartoum", Africa_Central },
             { "Africa/Johannesburg", Africa_Southern },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "timezone.excity.Asia/Singapore", "Singapur" },
             { "Europe/Belgrade", Europe_Central },
@@ -1731,16 +1709,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Tehran", Iran },
             { "timezone.excity.Asia/Nicosia", "Nikosia" },
             { "timezone.excity.Europe/Kiev", "Kiew" },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1759,6 +1727,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "Pacific/Noumea", New_Caledonia },
             { "Asia/Tbilisi", Georgia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Acory" },
             { "America/Montreal", America_Eastern },
             { "Asia/Makassar", Indonesia_Central },
@@ -1775,16 +1744,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Thimphu", Bhutan },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Rangoon", Myanmar },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Indian/Christmas", "G\u00f3downe kupy" },
@@ -1794,17 +1753,8 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Indian/Cocos", Cocos },
             { "Pacific/Tongatapu", Tonga },
             { "SystemV/YST9YDT", Alaska },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "Arctic/Longyearbyen", Europe_Central },
             { "America/Fort_Nelson", America_Mountain },
@@ -1816,16 +1766,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Ouagadougou", "Wagadugu" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/North_Dakota/New_Salem", America_Central },
             { "Australia/Melbourne", Australia_Eastern },
             { "Asia/Irkutsk", Irkutsk },
